

#define DEVICE_VENDOR_ID                            0x1E4E
#define DEVICE_PRODUCT_ID                           0


// All the interface number set at runtime for different product
#define INTERFACE_NUMBER_CD_ROM                 0
#define INTERFACE_NUMBER_NETWORK                0
#define INTERFACE_NUMBER_VIDEO_CONTROL          0
#define INTERFACE_NUMBER_VIDEO_STREAMING        0
#define INTERFACE_NUMBER_AUDIO_CONTROL          0
#define INTERFACE_NUMBER_AUDIO_STREAMING        0
#define INTERFACE_NUMBER_CUSTOMER               0


#define ENDPOINT_NUMBER_VIDEO_ISO_IN                0x89
#define ENDPOINT_NUMBER_AUDIO_ISO_IN                0x8A


#define VIDEO_DEVICE_CLASS_VERSION                  0x0100
#define AUDIO_DEVICE_CLASS_VERSION                  0x0100

#define TERMINAL_ID_CAMERA                          0x01
#define TERMINAL_ID_VIDEO_STREAMING                 0x02

#define UNIT_ID_PROCESSING                          0x03

#define UNIT_ID_EXTENSION                           0x04

#define TERMINAL_ID_MICROPHONE                      0x01
#define TERMINAL_ID_AUDIO_STREAMING                 0x02

#define UNIT_ID_FEATURE                             0x03


// ============================================================================
//
//         FOR VIDEO DESCRIPTOR USE
//
// ============================================================================


// FPS: 30, 50, 60
#define VIDEO_FRAME_FPS                     30

// 640x480, 1280x720, 1920x1080
#define VIDEO_FRAME_WIDTH                   640
#define VIDEO_FRAME_HEIGHT                  480


// (VIDEO_FRAME_WIDTH * VIDEO_FRAME_HEIGHT * 2)
#define VIDEO_FRAME_SIZE                    0x00096000

// (VIDEO_FRAME_WIDTH * VIDEO_FRAME_HEIGHT * VIDEO_FRAME_FPS * 2 * 8)
#define VIDEO_FRAME_MIN_BIT_RATE            0x08CA0000
#define VIDEO_FRAME_MAX_BIT_RATE            0x08CA0000

// Frame Interval = (1 /FPS / 0.0000001) = (10000000 / VIDEO_FRAME_FPS) 
#define VIDEO_FRAME_INTERVAL_FPS            0x00051615           


// ============================================================================
//
// Internal Definitions
//
// ============================================================================
#define STRING_INDEX_DEVICE_SERIAL_NUMBER   3
#define STRING_INDEX_INTERFACE_NETWORK      5




#define W2B(Value)          (0xFF & (SWAP_U16(Value) >> 8)), (0xFF & SWAP_U16(Value))
#define DW2B(Value)         (0xFF & (SWAP_U32(Value) >> 24)), (0xFF & (SWAP_U32(Value) >> 16)), (0xFF & (SWAP_U32(Value) >> 8)), (0xFF & SWAP_U32(Value))




U8 code gDeviceDescSs[] =                   // #define SECTION_ID_DEVICE_DESCRIPTOR_SS
{
    sizeof(struct _DEVICE_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_DEVICE,                 // bDescriptorType
    0x00, 0x03,     // bcdUSB
    0xEF,           // bDeviceClass
    0x02,           // bDeviceSubClass
    0x01,           // bDeviceProtocol
    0x09,           // bMaxPacketSize0
    W2B(DEVICE_VENDOR_ID),                  // idVendor
    W2B(DEVICE_PRODUCT_ID),                 // idProduct
    0x00, 0x01,     // bcdDevice
    0x06,           // iManufacturer
    0x07,           // iProduct
    STRING_INDEX_DEVICE_SERIAL_NUMBER,                  // iSerialNumber
    0x01            // bNumConfigurations
};


U8 code gDeviceDescHs[] =                   // #define SECTION_ID_DEVICE_DESCRIPTOR_HS
{
    sizeof(struct _DEVICE_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_DEVICE,                 // bDescriptorType
    0x10, 0x02,     // bcdUSB
    0xEF,           // bDeviceClass
    0x02,           // bDeviceSubClass
    0x01,           // bDeviceProtocol
    0x40,           // bMaxPacketSize0
    W2B(DEVICE_VENDOR_ID),                  // idVendor
    W2B(DEVICE_PRODUCT_ID),                 // idProduct
    0x00, 0x01,     // bcdDevice
    0x06,           // iManufacturer
    0x07,           // iProduct
    STRING_INDEX_DEVICE_SERIAL_NUMBER,                  // iSerialNumber
    0x01            // bNumConfigurations
};


U8 code gDeviceDescFs[] =                   // #define SECTION_ID_DEVICE_DESCRIPTOR_FS
{
    sizeof(struct _DEVICE_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_DEVICE,                 // bDescriptorType
    0x00, 0x02,     // bcdUSB
    0xEF,           // bDeviceClass
    0x02,           // bDeviceSubClass
    0x01,           // bDeviceProtocol
    0x40,           // bMaxPacketSize0
    W2B(DEVICE_VENDOR_ID),                  // idVendor
    W2B(DEVICE_PRODUCT_ID),                 // idProduct
    0x00, 0x01,     // bcdDevice
    0x06,           // iManufacturer
    0x07,           // iProduct
    STRING_INDEX_DEVICE_SERIAL_NUMBER,                  // iSerialNumber
    0x01            // bNumConfigurations
};


U8 code gCustomerDeviceDescSs[] =                    // #define SECTION_ID_CUSTOMER_DEVICE_DESCRIPTOR_SS
{
    sizeof(struct _DEVICE_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_DEVICE,                 // bDescriptorType
    0x00, 0x03,     // bcdUSB
    0x00,           // bDeviceClass
    0x00,           // bDeviceSubClass
    0x00,           // bDeviceProtocol
    0x09,           // bMaxPacketSize0
    W2B(DEVICE_VENDOR_ID),                  // idVendor
    W2B(DEVICE_PRODUCT_ID),                 // idProduct
    0x00, 0x01,     // bcdDevice
    0x00,           // iManufacturer
    0x00,           // iProduct
    STRING_INDEX_DEVICE_SERIAL_NUMBER,           // iSerialNumber
    0x01            // bNumConfigurations
};


U8 code gCustomerDeviceDescHs[] =                    // #define SECTION_ID_CUSTOMER_DEVICE_DESCRIPTOR_HS
{
    sizeof(struct _DEVICE_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_DEVICE,                 // bDescriptorType
    0x10, 0x02,     // bcdUSB
    0x00,           // bDeviceClass
    0x00,           // bDeviceSubClass
    0x00,           // bDeviceProtocol
    0x40,           // bMaxPacketSize0
    W2B(DEVICE_VENDOR_ID),                  // idVendor
    W2B(DEVICE_PRODUCT_ID),                 // idProduct
    0x00, 0x01,     // bcdDevice
    0x00,           // iManufacturer
    0x00,           // iProduct
    STRING_INDEX_DEVICE_SERIAL_NUMBER,           // iSerialNumber
    0x01            // bNumConfigurations
};


U8 code gCustomerDeviceDescFs[] =                    // #define SECTION_ID_CUSTOMER_DEVICE_DESCRIPTOR_FS
{
    sizeof(struct _DEVICE_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_DEVICE,                 // bDescriptorType
    0x00, 0x02,     // bcdUSB
    0x00,           // bDeviceClass
    0x00,           // bDeviceSubClass
    0x00,           // bDeviceProtocol
    0x40,           // bMaxPacketSize0
    W2B(DEVICE_VENDOR_ID),                  // idVendor
    W2B(DEVICE_PRODUCT_ID),                 // idProduct
    0x00, 0x01,     // bcdDevice
    0x00,           // iManufacturer
    0x00,           // iProduct
    STRING_INDEX_DEVICE_SERIAL_NUMBER,           // iSerialNumber
    0x01            // bNumConfigurations
};




U8 code gDeviceQualifierDesc[] =                    // #define SECTION_ID_DEVICE_QUALIFER_DESCRIPTOR
{
    sizeof(struct _DEVICE_QUALIFIER_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_DEVICE_QUALIFIER,                   // bDescriptorType
    0x00, 0x02,                                         // bcdUSB
    0xEF,                                               // bDeviceClass
    0x02,                                               // bDeviceSubClass
    0x01,                                               // bDeviceProtocol
    0x40,                                               // bMaxPacketSize0
    0x01,                                               // bNumConfigurations
    0x00                                                // bReserved
};


U8 code gConfigDescSs_Base[] =                          // #define SECTION_ID_CONFIGURE_SS_BASE 
{
    //
    // Configuration Descriptor ===========================
    //
    sizeof(struct _CONFIGURATION_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_CONFIGURATION,                      // bDescriptorType
    0x00, 0x00,     // wTotalLength     (Be set at run time)
    0x00,           // bNumInterfaces   
    0x01,           // bConfigurationValue
    0x00,           // iConfiguration
    0xA0,           // bmAttributes
    0x4B,           // bMaxPower
};


U8 code gConfigDescSs_CDROM[] =                          // #define SECTION_ID_CONFIGURE_SS_CDROM 
{
    //
    // Interface Descriptor - CD ROM ======================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),               // bLength
    DESCRIPTOR_TYPE_INTERFACE,                          // bDescriptorType
    INTERFACE_NUMBER_CD_ROM,                            // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x02,           // bNumEndpoints
    0x08,           // bInterfaceClass
    0x06,           // bInterfaceSubClass
    0x50,           // bInterfaceProtocol
    0x00,           // iInterface

        //
        // Endpoint Descriptor - MSC OUT ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                           // bDescriptorType
    0x01,           // bEndpointAddress
    0x02,           // bmAttributes
    0x00, 0x04,     // wMaxPacketSize
    0x00,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                 // bDescriptorType
    0x0F,           // bMaxBurst
    0x00,           // bmAttributes
    0x00, 0x00,     // wBytesPerInterval

        //
        // Endpoint Descriptor - MSC IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                           // bDescriptorType
    0x82,           // bEndpointAddress
    0x02,           // bmAttributes,
    0x00, 0x04,     // wMaxPacketSize
    0x00,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                 // bDescriptorType
    0x0F,           // bMaxBurst
    0x00,           // bmAttributes
    0x00, 0x00,     // wBytesPerInterval
};


U8 code gConfigDescSs_HostLink[] =                              // #define SECTION_ID_CONFIGURE_SS_HOSTLINK
{
    //
    // Interface Descriptor - Network =====================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),               // bLength
    DESCRIPTOR_TYPE_INTERFACE,                          // bDescriptorType
    INTERFACE_NUMBER_NETWORK,                           // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x03,           // bNumEndpoints
    0xFF,           // bInterfaceClass
    0x00,           // bInterfaceSubClass
    0x00,           // bInterfaceProtocol
    STRING_INDEX_INTERFACE_NETWORK,                     // iInterface

        //
        // Endpoint Descriptor - DMA OUT ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                           // bDescriptorType
    0x05,           // bEndpointAddress
    0x02,           // bmAttributes
    0x00, 0x04,     // wMaxPacketSize
    0x00,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                 // bDescriptorType
    0x0F,           // bMaxBurst
    0x00,           // bmAttributes
    0x00, 0x00,     // wBytesPerInterval

        //
        // Endpoint Descriptor - DMA IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                           // bDescriptorType
    0x86,           // bEndpointAddress
    0x02,           // bmAttributes
    0x00, 0x04,     // wMaxPacketSize
    0x00,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                 // bDescriptorType
    0x0F,           // bMaxBurst
    0x00,           // bmAttributes
    0x00, 0x00,     // wBytesPerInterval

        //
        // Endpoint Descriptor - INTR IN ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                           // bDescriptorType
    0x84,           // bEndpointAddress
    0x03,           // bmAttributes
    0x40, 0x00,     // wMaxPacketSize
    0x01,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),      // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                 // bDescriptorType
    0x00,           // bMaxBurst
    0x00,           // bmAttributes
    0x40, 0x00,     // wBytesPerInterval
};


U8 code gConfigDescSs_Grabber[] =                               // #define SECTION_ID_CONFIGURE_SS_GRABBER
{
    //
    // Interface Association Descriptor - Video ===========
    //
    sizeof(struct _INTERFACE_ASSOCIATION_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE_ASSOCIATION,                      // bDescriptorType
    INTERFACE_NUMBER_VIDEO_CONTROL,                             // bFirstInterface
    0x02,           // bInterfaceCount
    INTERFACE_CLASS_CC_VIDEO,                                   // bFunctionClass
    INTERFACE_SUBCLASS_SC_VIDEO_INTERFACE_COLLECTION,           // bFunctionSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bFunctionProtocol
    0x08,           // iFunction

    //
    // Interface Descriptor - Video Control ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_CONTROL,                             // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOCONTROL,                         // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // VC Interface Header Descriptor =================
        //
    sizeof(struct _VC_INTERFACE_HEADER_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_HEADER,                               // bDescriptorSubType
    W2B(VIDEO_DEVICE_CLASS_VERSION),                            // bcdUVC
    0x4D, 0x00,     // wTotalLength
    0x00, 0x0E, 0x27, 0x07,                                     // dwClockFrequency (120 MHz)
    0x01,           // bInCollection
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // baInterfaceNr(1)

        //
        // Input Terminal Descriptor - Camera =============
        //
    sizeof(struct _CAMERA_TERMINAL_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_INPUT_TERMINAL,                       // bDescriptorSubtype
    TERMINAL_ID_CAMERA,                                         // bTerminalID
    W2B(TERMINAL_TYPE_ITT_CAMERA),                              // wTerminalType
    0x00,           // bAssocTerminal
    0x00,           // iTerminal
    0x00, 0x00,     // wObjectiveFocalLengthMin
    0x00, 0x00,     // wObjectiveFocalLengthMax
    0x00, 0x00,     // wOcularFocalLength
    0x03,           // bControlSize
    0x00, 0x00, 0x00,                                           // bmControls

        //
        // Processing Unit Descriptor =====================
        //
    sizeof(struct _PROCESSING_UNIT_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_PROCESSING_UNIT,                      // bDescriptorSubtype
    UNIT_ID_PROCESSING,                                         // bUnitID
    TERMINAL_ID_CAMERA,                                         // bSourceID
    0x00, 0x00,     // wMaxMultiplier
    0x02,           // bControlSize
    0x00, 0x00,                                                 // bmControls
    0x00,           // iProcessing


        //
        // Output Terminal Descriptor - Streaming =========
        //
    sizeof(struct _OUTPUT_TERMINAL_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_OUTPUT_TERMINAL,                      // bDescriptorSubtype
    TERMINAL_ID_VIDEO_STREAMING,                                // bTerminalID
    W2B(TERMINAL_TYPE_TT_STREAMING),                            // wTerminalType
    0x00,           // bAssocTerminal
    UNIT_ID_EXTENSION,                                          // bSourceID
    0x00,           // iTerminal

        //
        // Extension Unit Descriptor 
        //
    sizeof(struct _EXTENSION_UNIT_DESCRIPTOR),                  // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_EXTENSION_UNIT,                       // bDescriptorSubtype
    UNIT_ID_EXTENSION,                                          // bUnitID
    0x5B, 0x12, 0x6D, 0xC6,                                     // guidExtensionCode - Data 1
    0x80, 0x04,                                                 // guidExtensionCode - Data 2
    0x44, 0x08,                                                 // guidExtensionCode - Data 3
    0x8C, 0x26,                                                 // guidExtensionCode - Data 4
    0xB8, 0x36, 0x3A, 0x84, 0xDE, 0x63,                         // guidExtensionCode - Data 4
    //5B126DC6-8004-4408-8C26-B8363A84DE63
    0x03,                                                       // bNumControls
    0x01,                                                       // bNrInPins
    UNIT_ID_PROCESSING,                                         // baSourceID
    0x01,                                                       // bControlSize
    0x07,                                                       // bmControls[1]
    0x00,                                                       // iExtension


    //
    // Interface Descriptor - Video Streaming 0 ===========
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // VS Interface Input Header Descriptor =========== (15bytes)
        //
    sizeof(struct _VS_INTERFACE_INPUT_HEADER_DESCRIPTOR),       // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_INPUT_HEADER,                         // bDescriptorSubtype
    0x02,           // bNumFormats
    0x7D, 0x00,     // wTotalLength
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x00,           // bmInfo
    TERMINAL_ID_VIDEO_STREAMING,                                // bTerminalLink
    0x00,           // bStillCaptureMethod
    0x00,           // bTriggerSupport
    0x00,           // bTriggerUsage
    0x01,           // bControlSize
    0x00,           // bmaControls(1)
    0x00,           // bmaControls(2)

        //
        // Payload Format Descriptor - MJPEG ============== (11bytes)
        //
    sizeof(struct _MOTION_JPEG_VIDEO_FORMAT_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FORMAT_MJPEG,                         // bDescriptorSubtype
    FORMAT_INDEX_MJPEG,                                         // bFormatIndex
    0x01,           // bNumFrameDescriptors
    0x00,           // bmFlags
    FRAME_INDEX_MJPEG,                                          // bDefaultFrameIndex
    0x00,           // bAspectRatioX
    0x00,           // bAspectRatioY
    0x00,           // bmInterlaceFlags
    0x00,           // bCopyProtect

            //
            // Video Frame Descriptor - 640 * 480 (30 FPS) (30bytes)
            //
    sizeof(struct _MOTION_JPEG_VIDEO_FRAME_DESCRIPTOR),         // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FRAME_MJPEG,                          // bDescriptorSubtype
    FRAME_INDEX_MJPEG,                                          // bFrameIndex
    0x00,           // bmCapabilities
    W2B(VIDEO_FRAME_WIDTH),                                     // wWidth
    W2B(VIDEO_FRAME_HEIGHT),                                    // wHeight
    DW2B(VIDEO_FRAME_MIN_BIT_RATE),                             // dwMinBitRate
    DW2B(VIDEO_FRAME_MAX_BIT_RATE),                             // dwMaxBitRate
    DW2B(VIDEO_FRAME_SIZE),                                     // dwMaxVideoFrameBufferSize
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwDefaultFrameInterval
    0x01,           // bFrameIntervalType
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwFrameInterval(1)

        //
        // Color Matching Descriptor ====================== (6bytes)
        //
    sizeof(struct _COLOR_MATCHING_DESCRIPTOR),                  // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_COLORFORMAT,                          // bDescriptorSubtype
    COLOR_PRIMARIES_BT_709_SRGB,                                // bColorPrimaries
    TRANSFER_CHARACTERISTICS_BT_709,                            // bTransferCharacteristics
    MATRIX_COEFFICIENTS_SMPTE_170M,                             // bMatrixCoefficients

        //
        // Payload Format Descriptor - Uncompressed ======= (27bytes)
        //
    sizeof(struct _UNCOMPRESSED_VIDEO_FORMAT_DESCRIPTOR),       // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FORMAT_UNCOMPRESSED,                  // bDescriptorSubtype
    FORMAT_INDEX_UNCOMPRESSED,                                  // bFormatIndex
    0x01,           // bNumFrameDescriptors
    0x59, 0x55, 0x59, 0x32,                                     // guidFormat - Data 1
    0x00, 0x00,                                                 // guidFormat - Data 2
    0x10, 0x00,                                                 // guidFormat - Data 3
    0x80, 0x00,                                                 // guidFormat - Data 4
    0x00, 0xAA, 0x00, 0x38, 0x9B, 0x71,                         // guidFormat - Data 4
    0x10,           // bBitsPerPixel
    FRAME_INDEX_UNCOMPRESSED,                                   // bDefaultFrameIndex
    0x00,           // bAspectRatioX
    0x00,           // bAspectRatioY
    0x00,           // bmInterlaceFlags
    0x00,           // bCopyProtect

            //
            // Video Frame Descriptor - 640 * 480 (30 FPS) (30bytes)
            //
    sizeof(struct _UNCOMPRESSED_VIDEO_FRAME_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FRAME_UNCOMPRESSED,                   // bDescriptorSubtype
    FRAME_INDEX_UNCOMPRESSED,                                   // bFrameIndex
    0x00,           // bmCapabilities
    W2B(VIDEO_FRAME_WIDTH),                                     // wWidth
    W2B(VIDEO_FRAME_HEIGHT),                                    // wHeight
    DW2B(VIDEO_FRAME_MIN_BIT_RATE),                             // dwMinBitRate
    DW2B(VIDEO_FRAME_MAX_BIT_RATE),                             // dwMaxBitRate
    DW2B(VIDEO_FRAME_SIZE),                                     // dwMaxVideoFrameBufferSize
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwDefaultFrameInterval
    0x01,           // bFrameIntervalType
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwFrameInterval(1)


        //
        // Color Matching Descriptor ====================== (6bytes)
        //
    sizeof(struct _COLOR_MATCHING_DESCRIPTOR),                  // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_COLORFORMAT,                          // bDescriptorSubtype
    COLOR_PRIMARIES_BT_709_SRGB,                                // bColorPrimaries
    TRANSFER_CHARACTERISTICS_BT_709,                            // bTransferCharacteristics
    MATRIX_COEFFICIENTS_SMPTE_170M,                             // bMatrixCoefficients

    //
    // Interface Descriptor - Video Streaming 1 ===========
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // bInterfaceNumber
    0x01,           // bAlternateSetting
    0x01,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // Endpoint Descriptor - ISO IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                        // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0x00, 0x04,     // wMaxPacketSize
    0x01,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),              // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                         // bDescriptorType
    0x0B,           // bMaxBurst         (12 - 1)
    0x02,           // bmAttributes      ( 3 - 1)
    0x00, 0x90,     // wBytesPerInterval (1024 * 12 * 3)

    //
    // Interface Descriptor - Video Streaming 1 alter 0x2 ===========
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // bInterfaceNumber
    0x02,           // bAlternateSetting
    0x01,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // Endpoint Descriptor - ISO IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                        // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0x00, 0x04,     // wMaxPacketSize
    0x01,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),              // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                         // bDescriptorType
    0x08,           // bMaxBurst
    0x01,           // bmAttributes
    0x00, 0x48,     // wBytesPerInterval

    //
    // Interface Association Descriptor - Audio ===========
    //
    sizeof(struct _INTERFACE_ASSOCIATION_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE_ASSOCIATION,                      // bDescriptorType
    INTERFACE_NUMBER_AUDIO_CONTROL,                             // bFirstInterface
    0x02,           // bInterfaceCount
    INTERFACE_CLASS_CC_AUDIO,                                   // bFunctionClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bFunctionSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bFunctionProtocol
    0x09,           // iFunction

    //
    // Interface Descriptor - Audio Control ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_CONTROL,                             // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOCONTROL,                         // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

        //
        // AC Interface Header Descriptor =================
        //
    sizeof(struct _AC_INTERFACE_HEADER_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_HEADER,                               // bDescriptorSubType
    W2B(AUDIO_DEVICE_CLASS_VERSION),                            // bcdADC
    0x26, 0x00,     // wTotalLength
    0x01,           // bInCollection
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // baInterfaceNr(1)

        //
        // Input Terminal Descriptor - Microphone =============
        //
    sizeof(struct _MICROPHONE_TERMINAL_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_INPUT_TERMINAL,                       // bDescriptorSubtype
    TERMINAL_ID_MICROPHONE,                                     // bTerminalID
    W2B(TERMINAL_TYPE_ITT_MICROPHONE),                          // wTerminalType
    0x00,           // bAssocTerminal
    0x01,           // bNrChannels
    0x00, 0x00,     // wChannelConfig
    0x00,           // iChannelNames
    0x00,           // iTerminal

        //
        // Output Terminal Descriptor - Audio Streaming =========
        //
    sizeof(struct _AUDIO_OUTPUT_TERMINAL_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_OUTPUT_TERMINAL,                      // bDescriptorSubtype
    TERMINAL_ID_AUDIO_STREAMING,                                // bTerminalID
    W2B(TERMINAL_TYPE_TT_STREAMING),                            // wTerminalType
    0x00,           // bAssocTerminal
    UNIT_ID_FEATURE,                                            // bSourceID
    0x00,           // iTerminal

        //
        // Feature Unit Descriptor =====================
        //
    sizeof(struct _FEATURE_UNIT_DESCRIPTOR),                    // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_FEATURE_UNIT,                         // bDescriptorSubtype
    UNIT_ID_FEATURE,                                            // bUnitID
    TERMINAL_ID_MICROPHONE,                                     // bSourceID
    0x01,           // bControlSize
    0x01,           // bmaControls
    0x00,           // iFeature

    //
    // Interface Descriptor - Audio Streaming 0 ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

    //
    // Interface Descriptor - Audio Streaming 1 ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // bInterfaceNumber
    0x01,           // bAlternateSetting
    0x01,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

        //
        // AC Interface AS General Descriptor
        //
    sizeof(struct _AS_INTERFACE_GENERAL_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AS_GENERAL,                              // bDescriptorSubtype
    TERMINAL_ID_AUDIO_STREAMING,                                // bTerminalLink
    0x01,           // bDelay
    0x01, 0x00,     // wFormatTag

        //
        // AC Interface Format Type Descriptor
        //
    sizeof(struct _AS_INTERFACE_FORMAT_TYPE_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AS_FORMAT_TYPE,                          // bDescriptorSubtype
    AUDIO_FORMAT_TYPE_I,                                        // bFormatType  
    AUDIO_NUMBER_OF_CHANNEL_STEREO,                             // bNrChannels
    0x02,               // bSubframeSize
    0x10,               // bBitResolution
    0x02,               // bSamFreqType
    0x44, 0xAC, 0x00,   // tSamFreq             (44.1K)
    0x80, 0xBB, 0x00,   // tSamFreq             (48K)

        //
        // Endpoint Descriptor - Isochronous IN
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                        // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_AUDIO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0xC0, 0x00,     // wMaxPacketSize                   (192Bytes)
    0x04,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),              // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                         // bDescriptorType
    0x00,           // bMaxBurst
    0x00,           // bmAttributes
    0xC0, 0x00,     // wBytesPerInterval                (192Bytes)

        //
        // AC Endpoint Descriptor
        //
    sizeof(struct _AS_ENDPOINT_GENERAL_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_ENDPOINT,                                // bDescriptorType
    DESCRIPTOR_SUBTYPE_EP_GENERAL,                              // bDescriptorSubType
    0x01,           // bmAttributes
    0x00,           // bLockDelayUnits
    0x00, 0x00,     // wLockDelay
};


U8 code gConfigDescSs_Customer[] =                    // #define SECTION_ID_CONFIGURE_SS_CUSTOMER
{
    //
    // Interface Descriptor  =====================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE,                      // bDescriptorType
    INTERFACE_NUMBER_CUSTOMER,                      // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x02,           // bNumEndpoints
    0xFF,           // bInterfaceClass
    0x00,           // bInterfaceSubClass
    0x00,           // bInterfaceProtocol
    0x00,           // iInterface

        //
        // Endpoint Descriptor - ISO IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                        // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0x00, 0x04,     // wMaxPacketSize
    0x01,           // bInterval              // bInterval

    ssizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),              // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                         // bDescriptorType
    0x0B,           // bMaxBurst         (12 - 1)
    0x02,           // bmAttributes      ( 3 - 1)
    0x00, 0x90,     // wBytesPerInterval (1024 * 12 * 3)

        //
        // Endpoint Descriptor -  ISO IN
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                        // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_AUDIO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0xC0, 0x00,     // wMaxPacketSize                   (192Bytes)
    0x04,           // bInterval

    sizeof(struct _ENDPOINT_COMPANION_DESCRIPTOR),              // bLength
    DESCRIPTOR_TYPE_ENDPOINT_COMPANION,                         // bDescriptorType
    0x00,           // bMaxBurst
    0x00,           // bmAttributes
    0xC0, 0x00,     // wBytesPerInterval                (192Bytes)

 };


U8 code gConfigDescHs_Base[] =                                  // #define SECTION_ID_CONFIGURE_HS_BASE
{
    //
    // Configuration Descriptor ===========================
    //
    sizeof(struct _CONFIGURATION_DESCRIPTOR),       // bLength
    DESCRIPTOR_TYPE_CONFIGURATION,                  // bDescriptorType
    0x00, 0x00,     // wTotalLength     (Be set at run time)
    0x00,           // bNumInterfaces
    0x01,           // bConfigurationValue
    0x00,           // iConfiguration
    0xA0,           // bmAttributes
    0x4B,           // bMaxPower
};


U8 code gConfigDescHs_CDROM[] =                                  // #define SECTION_ID_CONFIGURE_HS_CDROM
{
    //
    // Interface Descriptor - CD ROM ======================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE,                      // bDescriptorType
    INTERFACE_NUMBER_CD_ROM,                        // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x02,           // bNumEndpoints
    0x08,           // bInterfaceClass
    0x06,           // bInterfaceSubClass
    0x50,           // bInterfaceProtocol
    0x00,           // iInterface

        //
        // Endpoint Descriptor - MSC OUT ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x01,           // bEndpointAddress
    0x02,           // bmAttributes
    0x00, 0x02,     // wMaxPacketSize
    0x00,           // bInterval

        //
        // Endpoint Descriptor - MSC IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x82,           // bEndpointAddress
    0x02,           // bmAttributes
    0x00, 0x02,     // wMaxPacketSize
    0x00,           // bInterval
};


U8 code gConfigDescHs_HostLink[] =                              // #define SECTION_ID_CONFIGURE_HS_HOSTLINK
{
    //
    // Interface Descriptor - Network =====================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE,                      // bDescriptorType
    INTERFACE_NUMBER_NETWORK,                       // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x03,           // bNumEndpoints
    0xFF,           // bInterfaceClass
    0x00,           // bInterfaceSubClass
    0x00,           // bInterfaceProtocol
    STRING_INDEX_INTERFACE_NETWORK,                 // iInterface

        //
        // Endpoint Descriptor - DMA OUT ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x05,           // bEndpointAddress
    0x02,           // bmAttributes
    0x00, 0x02,     // wMaxPacketSize
    0x00,           // bInterval

        //
        // Endpoint Descriptor - DMA IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x86,           // bEndpointAddress
    0x02,           // bmAttributes
    0x00, 0x02,     // wMaxPacketSize
    0x00,           // bInterval

        //
        // Endpoint Descriptor - INTR IN ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x84,           // bEndpointAddress
    0x03,           // bmAttributes
    0x40, 0x00,     // wMaxPacketSize
    0x01,           // bInterval
};


U8 code gConfigDescHs_Grabber[] =                               // #define SECTION_ID_CONFIGURE_HS_GRABBER
{
    //
    // Interface Association Descriptor - Video ===========
    //
    sizeof(struct _INTERFACE_ASSOCIATION_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE_ASSOCIATION,                      // bDescriptorType
    INTERFACE_NUMBER_VIDEO_CONTROL,                             // bFirstInterface
    0x02,           // bInterfaceCount
    INTERFACE_CLASS_CC_VIDEO,                                   // bFunctionClass
    INTERFACE_SUBCLASS_SC_VIDEO_INTERFACE_COLLECTION,           // bFunctionSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bFunctionProtocol
    0x08,           // iFunction

    //
    // Interface Descriptor - Video Control ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_CONTROL,                             // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOCONTROL,                         // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // VC Interface Header Descriptor =================
        //
    sizeof(struct _VC_INTERFACE_HEADER_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_HEADER,                               // bDescriptorSubType
    W2B(VIDEO_DEVICE_CLASS_VERSION),                            // bcdUVC
    0x4D, 0x00,     // wTotalLength
    0x00, 0x0E, 0x27, 0x07,                                     // dwClockFrequency (120 MHz)
    0x01,           // bInCollection
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // baInterfaceNr(1)

        //
        // Input Terminal Descriptor - Camera =============
        //
    sizeof(struct _CAMERA_TERMINAL_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_INPUT_TERMINAL,                       // bDescriptorSubtype
    TERMINAL_ID_CAMERA,                                         // bTerminalID
    W2B(TERMINAL_TYPE_ITT_CAMERA),                              // wTerminalType
    0x00,           // bAssocTerminal
    0x00,           // iTerminal
    0x00, 0x00,     // wObjectiveFocalLengthMin
    0x00, 0x00,     // wObjectiveFocalLengthMax
    0x00, 0x00,     // wOcularFocalLength
    0x03,           // bControlSize
    0x00, 0x00, 0x00,                                           // bmControls

        //
        // Processing Unit Descriptor =====================
        //
    sizeof(struct _PROCESSING_UNIT_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptor
    DESCRIPTOR_SUBTYPE_VC_PROCESSING_UNIT,                      // bDescriptorSubtype
    UNIT_ID_PROCESSING,                                         // bUnitID
    TERMINAL_ID_CAMERA,                                         // bSourceID
    0x00, 0x00,     // wMaxMultiplier
    0x02,           // bControlSize
    0x00, 0x00,                                                 // bmControls
    0x00,           // iProcessing


        //
        // Output Terminal Descriptor - Streaming =========
        //
    sizeof(struct _OUTPUT_TERMINAL_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_OUTPUT_TERMINAL,                      // bDescriptorSubtype
    TERMINAL_ID_VIDEO_STREAMING,                                // bTerminalID
    W2B(TERMINAL_TYPE_TT_STREAMING),                            // wTerminalType
    0x00,           // bAssocTerminal
    UNIT_ID_EXTENSION,                                          // bSourceID
    0x00,           // iTerminal

        //
        // Extension Unit Descriptor 
        //
    sizeof(struct _EXTENSION_UNIT_DESCRIPTOR),                  // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_EXTENSION_UNIT,                       // bDescriptorSubtype
    UNIT_ID_EXTENSION,                                          // bUnitID
    0x5B, 0x12, 0x6D, 0xC6,                                     // guidExtensionCode - Data 1
    0x80, 0x04,                                                 // guidExtensionCode - Data 2
    0x44, 0x08,                                                 // guidExtensionCode - Data 3
    0x8C, 0x26,                                                 // guidExtensionCode - Data 4
    0xB8, 0x36, 0x3A, 0x84, 0xDE, 0x63,                         // guidExtensionCode - Data 4
    //5B126DC6-8004-4408-8C26-B8363A84DE63
    0x03,                                                       // bNumControls
    0x01,                                                       // bNrInPins
    UNIT_ID_PROCESSING,                                         // baSourceID
    0x01,                                                       // bControlSize
    0x07,                                                       // bmControls[1]
    0x00,                                                       // iExtension


    //
    // Interface Descriptor - Video Streaming 0 ===========
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // VS Interface Input Header Descriptor =========== (14bytes)
        //
    0x0E,                                                       // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_INPUT_HEADER,                         // bDescriptorSubtype
    0x01,           // bNumFormats
    0x3D, 0x00,     // wTotalLength
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x00,           // bmInfo
    TERMINAL_ID_VIDEO_STREAMING,                                // bTerminalLink
    0x00,           // bStillCaptureMethod
    0x00,           // bTriggerSupport
    0x00,           // bTriggerUsage
    0x01,           // bControlSize
    0x00,           // bmaControls(1)

        //
        // Payload Format Descriptor - MJPEG ============== (11bytes)
        //
    sizeof(struct _MOTION_JPEG_VIDEO_FORMAT_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FORMAT_MJPEG,                         // bDescriptorSubtype
    FORMAT_INDEX_MJPEG,                                         // bFormatIndex
    0x01,           // bNumFrameDescriptors
    0x00,           // bmFlags
    FRAME_INDEX_MJPEG,                                          // bDefaultFrameIndex
    0x00,           // bAspectRatioX
    0x00,           // bAspectRatioY
    0x00,           // bmInterlaceFlags
    0x00,           // bCopyProtect

            //
            // Video Frame Descriptor - 640 * 480 (30 FPS) (30bytes)
            //
    sizeof(struct _MOTION_JPEG_VIDEO_FRAME_DESCRIPTOR),         // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FRAME_MJPEG,                          // bDescriptorSubtype
    FRAME_INDEX_MJPEG,                                          // bFrameIndex
    0x00,           // bmCapabilities
    W2B(VIDEO_FRAME_WIDTH),                                     // wWidth
    W2B(VIDEO_FRAME_HEIGHT),                                    // wHeight
    DW2B(VIDEO_FRAME_MIN_BIT_RATE),                             // dwMinBitRate
    DW2B(VIDEO_FRAME_MAX_BIT_RATE),                             // dwMaxBitRate
    DW2B(VIDEO_FRAME_SIZE),                                     // dwMaxVideoFrameBufferSize
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwDefaultFrameInterval
    0x01,           // bFrameIntervalType
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwFrameInterval(1)

        //
        // Color Matching Descriptor ====================== (6bytes)
        //
    sizeof(struct _COLOR_MATCHING_DESCRIPTOR),                  // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_COLORFORMAT,                          // bDescriptorSubtype
    COLOR_PRIMARIES_BT_709_SRGB,                                // bColorPrimaries
    TRANSFER_CHARACTERISTICS_BT_709,                            // bTransferCharacteristics
    MATRIX_COEFFICIENTS_SMPTE_170M,                             // bMatrixCoefficients

    //
    // Interface Descriptor - Video Streaming 1 ===========
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // bInterfaceNumber
    0x01,           // bAlternateSetting
    0x01,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // Endpoint Descriptor - ISO IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                        // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0x00, 0x14,     // wMaxPacketSize
    0x01,           // bInterval

    //
    // Interface Association Descriptor - Audio ===========
    //
    sizeof(struct _INTERFACE_ASSOCIATION_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE_ASSOCIATION,                      // bDescriptorType
    INTERFACE_NUMBER_AUDIO_CONTROL,                             // bFirstInterface
    0x02,           // bInterfaceCount
    INTERFACE_CLASS_CC_AUDIO,                                   // bFunctionClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bFunctionSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bFunctionProtocol
    0x09,           // iFunction

    //
    // Interface Descriptor - Audio Control ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_CONTROL,                             // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOCONTROL,                         // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

        //
        // AC Interface Header Descriptor =================
        //
    sizeof(struct _AC_INTERFACE_HEADER_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_HEADER,                               // bDescriptorSubType
    W2B(AUDIO_DEVICE_CLASS_VERSION),                            // bcdADC
    0x26, 0x00,     // wTotalLength
    0x01,           // bInCollection
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // baInterfaceNr(1)

        //
        // Input Terminal Descriptor - Microphone =============
        //
    sizeof(struct _MICROPHONE_TERMINAL_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_INPUT_TERMINAL,                       // bDescriptorSubtype
    TERMINAL_ID_MICROPHONE,                                     // bTerminalID
    W2B(TERMINAL_TYPE_ITT_MICROPHONE),                          // wTerminalType
    0x00,           // bAssocTerminal
    0x01,           // bNrChannels
    0x00, 0x00,     // wChannelConfig
    0x00,           // iChannelNames
    0x00,           // iTerminal

        //
        // Output Terminal Descriptor - Audio Streaming =========
        //
    sizeof(struct _AUDIO_OUTPUT_TERMINAL_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_OUTPUT_TERMINAL,                      // bDescriptorSubtype
    TERMINAL_ID_AUDIO_STREAMING,                                // bTerminalID
    W2B(TERMINAL_TYPE_TT_STREAMING),                            // wTerminalType
    0x00,           // bAssocTerminal
    UNIT_ID_FEATURE,                                            // bSourceID
    0x00,           // iTerminal

        //
        // Feature Unit Descriptor =====================
        //
    sizeof(struct _FEATURE_UNIT_DESCRIPTOR),                    // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_FEATURE_UNIT,                         // bDescriptorSubtype
    UNIT_ID_FEATURE,                                            // bUnitID
    TERMINAL_ID_MICROPHONE,                                     // bSourceID
    0x01,           // bControlSize
    0x01,           // bmaControls
    0x00,           // iFeature

    //
    // Interface Descriptor - Audio Streaming 0 ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

    //
    // Interface Descriptor - Audio Streaming 1 ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // bInterfaceNumber
    0x01,           // bAlternateSetting
    0x01,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

        //
        // AC Interface AS General Descriptor
        //
    sizeof(struct _AS_INTERFACE_GENERAL_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AS_GENERAL,                              // bDescriptorSubtype
    TERMINAL_ID_AUDIO_STREAMING,                                // bTerminalLink
    0x01,           // bDelay
    0x01, 0x00,     // wFormatTag

        //
        // AC Interface Format Type Descriptor
        //
    sizeof(struct _AS_INTERFACE_FORMAT_TYPE_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AS_FORMAT_TYPE,                          // bDescriptorSubtype
    AUDIO_FORMAT_TYPE_I,                                        // bFormatType  
    AUDIO_NUMBER_OF_CHANNEL_STEREO,                             // bNrChannels
    0x02,               // bSubframeSize
    0x10,               // bBitResolution
    0x02,               // bSamFreqType
    0x44, 0xAC, 0x00,   // tSamFreq             (44.1K)
    0x80, 0xBB, 0x00,   // tSamFreq             (48K)

        //
        // Endpoint Descriptor - Isochronous IN
        //
    sizeof(struct _STANDARD_AS_ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_AUDIO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0xC0, 0x00,     // wMaxPacketSize                   (192Bytes)
    0x04,           // bInterval
    0x00,           // bRefresh
    0x00,           // bSynchAddress

        //
        // AC Endpoint Descriptor
        //
    sizeof(struct _AS_ENDPOINT_GENERAL_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_ENDPOINT,                                // bDescriptorType
    DESCRIPTOR_SUBTYPE_EP_GENERAL,                              // bDescriptorSubType
    0x01,           // bmAttributes
    0x00,           // bLockDelayUnits
    0x00, 0x00,     // wLockDelay
};



U8 code gConfigDescHs_Customer[] =                    // #define SECTION_ID_CONFIGURE_HS_CUSTOMER
{
    //
    // Interface Descriptor  =====================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE,                      // bDescriptorType
    INTERFACE_NUMBER_CUSTOMER,                      // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x02,           // bNumEndpoints
    0xFF,           // bInterfaceClass
    0x00,           // bInterfaceSubClass
    0x00,           // bInterfaceProtocol
    0x00,           // iInterface

        //
        // Endpoint Descriptor - ISO IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                   // bEndpointAddress
    0x05,                 // bmAttributes
    0x00, 0x14,           // wMaxPacketSize
    0x01,                 // bInterval

        //
        // Endpoint Descriptor -  ISO IN
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                      // bDescriptorType
    ENDPOINT_NUMBER_AUDIO_ISO_IN,                  // bEndpointAddress
    0x05,                 // bmAttributes
    0xC0, 0x00,           // wMaxPacketSize                (192Bytes)
    0x04,                 // bInterval

 };
U8 code gConfigDescFs_Base[] =                                  // #define SECTION_ID_CONFIGURE_FS_BASE
{
    //
    // Configuration Descriptor ===========================
    //
    sizeof(struct _CONFIGURATION_DESCRIPTOR),       // bLength
    DESCRIPTOR_TYPE_CONFIGURATION,                  // bDescriptorType
    0x00, 0x00,     // wTotalLength     (Be set at run time)
    0x00,           // bNumInterfaces   
    0x01,           // bConfigurationValue
    0x00,           // iConfiguration
    0xA0,           // bmAttributes
    0x4B,           // bMaxPower
};


U8 code gConfigDescFs_CDROM[] =                                 // #define SECTION_ID_CONFIGURE_FS_CDROM
{
    //
    // Interface Descriptor - CD ROM ======================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE,                      // bDescriptorType
    INTERFACE_NUMBER_CD_ROM,                        // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x02,           // bNumEndpoints
    0x08,           // bInterfaceClass
    0x06,           // bInterfaceSubClass
    0x50,           // bInterfaceProtocol
    0x00,           // iInterface

        //
        // Endpoint Descriptor - MSC OUT ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x01,           // bEndpointAddress
    0x02,           // bmAttributes
    0x40, 0x00,     // wMaxPacketSize
    0x00,           // bInterval

        //
        // Endpoint Descriptor - MSC IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x82,           // bEndpointAddress
    0x02,           // bmAttributes
    0x40, 0x00,     // wMaxPacketSize
    0x00,           // bInterval
};


U8 code gConfigDescFs_HostLink[] =                              // #define SECTION_ID_CONFIGURE_FS_HOSTLINK
{
    //
    // Interface Descriptor - Network =====================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE,                      // bDescriptorType
    INTERFACE_NUMBER_NETWORK,                       // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x03,           // bNumEndpoints
    0xFF,           // bInterfaceClass
    0x00,           // bInterfaceSubClass
    0x00,           // bInterfaceProtocol
    STRING_INDEX_INTERFACE_NETWORK,                 // iInterface

        //
        // Endpoint Descriptor - DMA OUT ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x05,           // bEndpointAddress
    0x02,           // bmAttributes
    0x40, 0x00,     // wMaxPacketSize
    0x00,           // bInterval

        //
        // Endpoint Descriptor - DMA IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x86,           // bEndpointAddress
    0x02,           // bmAttributes
    0x40, 0x00,     // wMaxPacketSize
    0x00,           // bInterval

        //
        // Endpoint Descriptor - INTR IN ==================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    0x84,           // bEndpointAddress
    0x03,           // bmAttributes
    0x40, 0x00,     // wMaxPacketSize
    0x01,           // bInterval
};


U8 code gConfigDescFs_Grabber[] =                               // #define SECTION_ID_CONFIGURE_FS_GRABBER
{
    //
    // Interface Association Descriptor - Video ===========
    //
    sizeof(struct _INTERFACE_ASSOCIATION_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE_ASSOCIATION,                      // bDescriptorType
    INTERFACE_NUMBER_VIDEO_CONTROL,                             // bFirstInterface
    0x02,           // bInterfaceCount
    INTERFACE_CLASS_CC_VIDEO,                                   // bFunctionClass
    INTERFACE_SUBCLASS_SC_VIDEO_INTERFACE_COLLECTION,           // bFunctionSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bFunctionProtocol
    0x08,           // iFunction

    //
    // Interface Descriptor - Video Control ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_CONTROL,                             // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOCONTROL,                         // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // VC Interface Header Descriptor =================
        //
    sizeof(struct _VC_INTERFACE_HEADER_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_HEADER,                               // bDescriptorSubType
    W2B(VIDEO_DEVICE_CLASS_VERSION),                            // bcdUVC
    0x4D, 0x00,     // wTotalLength
    0x00, 0x0E, 0x27, 0x07,                                     // dwClockFrequency (120 MHz)
    0x01,           // bInCollection
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // baInterfaceNr(1)

        //
        // Input Terminal Descriptor - Camera =============
        //
    sizeof(struct _CAMERA_TERMINAL_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_INPUT_TERMINAL,                       // bDescriptorSubtype
    TERMINAL_ID_CAMERA,                                         // bTerminalID
    W2B(TERMINAL_TYPE_ITT_CAMERA),                              // wTerminalType
    0x00,           // bAssocTerminal
    0x00,           // iTerminal
    0x00, 0x00,     // wObjectiveFocalLengthMin
    0x00, 0x00,     // wObjectiveFocalLengthMax
    0x00, 0x00,     // wOcularFocalLength
    0x03,           // bControlSize
    0x00, 0x00, 0x00,                                           // bmControls

        //
        // Processing Unit Descriptor =====================
        //
    sizeof(struct _PROCESSING_UNIT_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptor
    DESCRIPTOR_SUBTYPE_VC_PROCESSING_UNIT,                      // bDescriptorSubtype
    UNIT_ID_PROCESSING,                                         // bUnitID
    TERMINAL_ID_CAMERA,                                         // bSourceID
    0x00, 0x00,     // wMaxMultiplier
    0x02,           // bControlSize
    0x00, 0x00,                                           // bmControls
    0x00,           // iProcessing


        //
        // Output Terminal Descriptor - Streaming =========
        //
    sizeof(struct _OUTPUT_TERMINAL_DESCRIPTOR),                 // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_OUTPUT_TERMINAL,                      // bDescriptorSubtype
    TERMINAL_ID_VIDEO_STREAMING,                                // bTerminalID
    W2B(TERMINAL_TYPE_TT_STREAMING),                            // wTerminalType
    0x00,           // bAssocTerminal
    UNIT_ID_EXTENSION,                                          // bSourceID
    0x00,           // iTerminal

        //
        // Extension Unit Descriptor
        //
    sizeof(struct _EXTENSION_UNIT_DESCRIPTOR),                  // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VC_EXTENSION_UNIT,                       // bDescriptorSubtype
    UNIT_ID_EXTENSION,                                          // bUnitID
    0x5B, 0x12, 0x6D, 0xC6,                                     // guidExtensionCode - Data 1
    0x80, 0x04,                                                 // guidExtensionCode - Data 2
    0x44, 0x08,                                                 // guidExtensionCode - Data 3
    0x8C, 0x26,                                                 // guidExtensionCode - Data 4
    0xB8, 0x36, 0x3A, 0x84, 0xDE, 0x63,                         // guidExtensionCode - Data 4
    //5B126DC6-8004-4408-8C26-B8363A84DE63
    0x03,                                                       // bNumControls
    0x01,                                                       // bNrInPins
    UNIT_ID_PROCESSING,                                         // baSourceID
    0x01,                                                       // bControlSize
    0x07,                                                       // bmControls[1]
    0x00,                                                       // iExtension



    //
    // Interface Descriptor - Video Streaming 0 ===========
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // VS Interface Input Header Descriptor =========== (14bytes)
        //
    0x0E,                                                       // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_INPUT_HEADER,                         // bDescriptorSubtype
    0x01,           // bNumFormats
    0x3D, 0x00,     // wTotalLength
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x00,           // bmInfo
    TERMINAL_ID_VIDEO_STREAMING,                                // bTerminalLink
    0x00,           // bStillCaptureMethod
    0x00,           // bTriggerSupport
    0x00,           // bTriggerUsage
    0x01,           // bControlSize
    0x00,           // bmaControls(1)

        //
        // Payload Format Descriptor - MJPEG ============== (11bytes)
        //
    sizeof(struct _MOTION_JPEG_VIDEO_FORMAT_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FORMAT_MJPEG,                         // bDescriptorSubtype
    FORMAT_INDEX_MJPEG,                                         // bFormatIndex
    0x01,           // bNumFrameDescriptors
    0x00,           // bmFlags
    FRAME_INDEX_MJPEG,                                          // bDefaultFrameIndex
    0x00,           // bAspectRatioX
    0x00,           // bAspectRatioY
    0x00,           // bmInterlaceFlags
    0x00,           // bCopyProtect

            //
            // Video Frame Descriptor - 640 * 480 (30 FPS) (30bytes)
            //
    sizeof(struct _MOTION_JPEG_VIDEO_FRAME_DESCRIPTOR),         // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_FRAME_MJPEG,                          // bDescriptorSubtype
    FRAME_INDEX_MJPEG,                                          // bFrameIndex
    0x00,           // bmCapabilities
    W2B(VIDEO_FRAME_WIDTH),                                     // wWidth
    W2B(VIDEO_FRAME_HEIGHT),                                    // wHeight
    DW2B(VIDEO_FRAME_MIN_BIT_RATE),                             // dwMinBitRate
    DW2B(VIDEO_FRAME_MAX_BIT_RATE),                             // dwMaxBitRate
    DW2B(VIDEO_FRAME_SIZE),                                     // dwMaxVideoFrameBufferSize
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwDefaultFrameInterval
    0x02,           // bFrameIntervalType
    DW2B(VIDEO_FRAME_INTERVAL_FPS),                             // dwFrameInterval(1)

        //
        // Color Matching Descriptor ====================== (6bytes)
        //
    sizeof(struct _COLOR_MATCHING_DESCRIPTOR),                  // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_VS_COLORFORMAT,                          // bDescriptorSubtype
    COLOR_PRIMARIES_BT_709_SRGB,                                // bColorPrimaries
    TRANSFER_CHARACTERISTICS_BT_709,                            // bTransferCharacteristics
    MATRIX_COEFFICIENTS_SMPTE_170M,                             // bMatrixCoefficients

    //
    // Interface Descriptor - Video Streaming 1 ===========
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_VIDEO_STREAMING,                           // bInterfaceNumber
    0x01,           // bAlternateSetting
    0x01,           // bNumEndpoints
    INTERFACE_CLASS_CC_VIDEO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_VIDEOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PC_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x08,           // iInterface

        //
        // Endpoint Descriptor - ISO IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),                        // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0xFF, 0x03,     // wMaxPacketSize
    0x01,           // bInterval

    //
    // Interface Association Descriptor - Audio ===========
    //
    sizeof(struct _INTERFACE_ASSOCIATION_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE_ASSOCIATION,                      // bDescriptorType
    INTERFACE_NUMBER_AUDIO_CONTROL,                             // bFirstInterface
    0x02,           // bInterfaceCount
    INTERFACE_CLASS_CC_AUDIO,                                   // bFunctionClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bFunctionSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bFunctionProtocol
    0x09,           // iFunction

    //
    // Interface Descriptor - Audio Control ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_CONTROL,                             // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOCONTROL,                         // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

        //
        // AC Interface Header Descriptor =================
        //
    sizeof(struct _AC_INTERFACE_HEADER_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_HEADER,                               // bDescriptorSubType
    W2B(AUDIO_DEVICE_CLASS_VERSION),                            // bcdADC
    0x26, 0x00,     // wTotalLength
    0x01,           // bInCollection
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // baInterfaceNr(1)

        //
        // Input Terminal Descriptor - Microphone =============
        //
    sizeof(struct _MICROPHONE_TERMINAL_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_INPUT_TERMINAL,                       // bDescriptorSubtype
    TERMINAL_ID_MICROPHONE,                                     // bTerminalID
    W2B(TERMINAL_TYPE_ITT_MICROPHONE),                          // wTerminalType
    0x00,           // bAssocTerminal
    0x01,           // bNrChannels
    0x00, 0x00,     // wChannelConfig
    0x00,           // iChannelNames
    0x00,           // iTerminal

        //
        // Output Terminal Descriptor - Audio Streaming =========
        //
    sizeof(struct _AUDIO_OUTPUT_TERMINAL_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_OUTPUT_TERMINAL,                      // bDescriptorSubtype
    TERMINAL_ID_AUDIO_STREAMING,                                // bTerminalID
    W2B(TERMINAL_TYPE_TT_STREAMING),                            // wTerminalType
    0x00,           // bAssocTerminal
    UNIT_ID_FEATURE,                                            // bSourceID
    0x00,           // iTerminal

        //
        // Feature Unit Descriptor =====================
        //
    sizeof(struct _FEATURE_UNIT_DESCRIPTOR),                    // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AC_FEATURE_UNIT,                         // bDescriptorSubtype
    UNIT_ID_FEATURE,                                            // bUnitID
    TERMINAL_ID_MICROPHONE,                                     // bSourceID
    0x01,           // bControlSize
    0x01,           // bmaControls
    0x00,           // iFeature

    //
    // Interface Descriptor - Audio Streaming 0 ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x00,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

    //
    // Interface Descriptor - Audio Streaming 1 ===============
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),                       // bLength
    DESCRIPTOR_TYPE_INTERFACE,                                  // bDescriptorType
    INTERFACE_NUMBER_AUDIO_STREAMING,                           // bInterfaceNumber
    0x01,           // bAlternateSetting
    0x01,           // bNumEndpoints
    INTERFACE_CLASS_CC_AUDIO,                                   // bInterfaceClass
    INTERFACE_SUBCLASS_SC_AUDIOSTREAMING,                       // bInterfaceSubClass
    INTERFACE_PROTOCOL_PR_PROTOCOL_UNDEFINED,                   // bInterfaceProtocol
    0x09,           // iInterface

        //
        // AC Interface AS General Descriptor
        //
    sizeof(struct _AS_INTERFACE_GENERAL_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AS_GENERAL,                              // bDescriptorSubtype
    TERMINAL_ID_AUDIO_STREAMING,                                // bTerminalLink
    0x01,           // bDelay
    0x01, 0x00,     // wFormatTag

        //
        // AC Interface Format Type Descriptor
        //
    sizeof(struct _AS_INTERFACE_FORMAT_TYPE_DESCRIPTOR),        // bLength
    DESCRIPTOR_TYPE_CS_INTERFACE,                               // bDescriptorType
    DESCRIPTOR_SUBTYPE_AS_FORMAT_TYPE,                          // bDescriptorSubtype
    AUDIO_FORMAT_TYPE_I,                                        // bFormatType  
    AUDIO_NUMBER_OF_CHANNEL_STEREO,                             // bNrChannels
    0x02,               // bSubframeSize
    0x10,               // bBitResolution
    0x02,               // bSamFreqType
    0x44, 0xAC, 0x00,   // tSamFreq             (44.1K)
    0x80, 0xBB, 0x00,   // tSamFreq             (48K)

        //
        // Endpoint Descriptor - Isochronous IN
        //
    sizeof(struct _STANDARD_AS_ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                                   // bDescriptorType
    ENDPOINT_NUMBER_AUDIO_ISO_IN,                               // bEndpointAddress
    0x05,           // bmAttributes
    0xC0, 0x00,     // wMaxPacketSize                   (192Bytes)
    0x04,           // bInterval
    0x00,           // bRefresh
    0x00,           // bSynchAddress

        //
        // AC Endpoint Descriptor
        //
    sizeof(struct _AS_ENDPOINT_GENERAL_DESCRIPTOR),             // bLength
    DESCRIPTOR_TYPE_CS_ENDPOINT,                                // bDescriptorType
    DESCRIPTOR_SUBTYPE_EP_GENERAL,                              // bDescriptorSubType
    0x01,           // bmAttributes
    0x00,           // bLockDelayUnits
    0x00, 0x00,     // wLockDelay
};


U8 code gConfigDescFs_Customer[] =                    // #define SECTION_ID_CONFIGURE_FS_CUSTOMER
{
    //
    // Interface Descriptor  =====================
    //
    sizeof(struct _INTERFACE_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_INTERFACE,                      // bDescriptorType
    INTERFACE_NUMBER_CUSTOMER,                      // bInterfaceNumber
    0x00,           // bAlternateSetting
    0x02,           // bNumEndpoints
    0xFF,           // bInterfaceClass
    0x00,           // bInterfaceSubClass
    0x00,           // bInterfaceProtocol
    0x00,           // iInterface

        //
        // Endpoint Descriptor - ISO IN ===================
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),            // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                       // bDescriptorType
    ENDPOINT_NUMBER_VIDEO_ISO_IN,                   // bEndpointAddress
    0x05,           // bmAttributes
    0xFF, 0x03,     // wMaxPacketSize
    0x01,           // bInterval

        //
        // Endpoint Descriptor -  ISO IN
        //
    sizeof(struct _ENDPOINT_DESCRIPTOR),           // bLength
    DESCRIPTOR_TYPE_ENDPOINT,                      // bDescriptorType
    ENDPOINT_NUMBER_AUDIO_ISO_IN,                  // bEndpointAddress
    0x05,           // bmAttributes
    0xC0, 0x00,     // wMaxPacketSize                   (192Bytes)
    0x04,           // bInterval

 };



U8 code gBosDesc[] =                                                    // #define SECTION_ID_BOS_DESCRIPTOR
{
    //
    // BOS Descriptor =====================================
    //
    sizeof(struct _BOS_DESCRIPTOR),                                     // bLength
    DESCRIPTOR_TYPE_BOS,                                                // bDescriptorType
    0x16, 0x00,                 // wTotalLength
    0x02,                       // bNumDeviceCaps

        //
        // USB 2.0 Extension Descriptor ===================
        //
    sizeof(struct _DEVICE_CAPABILITY_DESCRIPTOR_USB2_EXTENSION),        // bLength
    DESCRIPTOR_TYPE_DEVICE_CAPABILITY,                                  // bDescriptorType
    DEV_CAPABILITY_TYPE_USB2_EXTENSION,                                 // bDevCapabilityType
    0x06, 0x00, 0x00, 0x00,     // bmAttributes

        //
        // SuperSpeed Device Capabilities Descriptor ======
        //
    sizeof(struct _DEVICE_CAPABILITY_DESCRIPTOR_SUPER_SPEED),           // bLength
    DESCRIPTOR_TYPE_DEVICE_CAPABILITY,                                  // bDescriptorType
    DEV_CAPABILITY_TYPE_SUPER_SPEED,                                    // bDevCapabilityType
    0x00,                       // bmAttributes
    0x0E, 0x00,                 // wSpeedsSupported
    0x01,                       // bFunctionalitySupport
    DEV_CAPABILITY_U1_EXIT_LATENCY,                                     // bU1DevExitLat
    W2B(DEV_CAPABILITY_U2_EXIT_LATENCY)                                 // wU2DevExitLat
};




// ============================================================================
//
//         FOR VIDEO DESCRIPTOR USE
//
// ============================================================================

//
//      MJPG Huffman Table 
//

U8 code gMjpgHuffmanTable[] =           // #define SECTION_ID_MJPG_HUFFMAN_TABLE
{
    0x04, 0xa0, 0x00, 0x02, 0x00, 0x00, 0x03, 0x40, 0x00, 0x03, 0x60, 0x00, 0x03, 0x80, 0x00, 0x03,
    0xa0, 0x00, 0x03, 0xc0, 0x00, 0x04, 0xe0, 0x00, 0x05, 0xf0, 0x00, 0x06, 0xf8, 0x00, 0x07, 0xfc,
    0x00, 0x08, 0xfe, 0x00, 0x09, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0b, 0xff, 0x20,
    0x02, 0x00, 0x00, 0x04, 0xc0, 0x00, 0x05, 0xe0, 0x00, 0x06, 0xe8, 0x00, 0x06, 0xec, 0x00, 0x07,
    0xf4, 0x00, 0x07, 0xf6, 0x00, 0x08, 0xfa, 0x00, 0x09, 0xfc, 0x00, 0x09, 0xfc, 0x80, 0x09, 0xfd,
    0x00, 0x0a, 0xfe, 0x40, 0x0a, 0xfe, 0x80, 0x0b, 0xff, 0x00, 0x00, 0xff, 0xeb, 0x00, 0xff, 0xf5,
    0x02, 0x40, 0x00, 0x05, 0xd8, 0x00, 0x08, 0xf9, 0x00, 0x09, 0xfb, 0x80, 0x0a, 0xfe, 0x00, 0x0b,
    0xfe, 0xe0, 0x0c, 0xff, 0x60, 0x0c, 0xff, 0x70, 0x0f, 0xff, 0x80, 0x00, 0xff, 0xbe, 0x00, 0xff,
    0xc7, 0x00, 0xff, 0xd0, 0x00, 0xff, 0xd9, 0x00, 0xff, 0xe2, 0x00, 0xff, 0xec, 0x00, 0xff, 0xf6,
    0x03, 0x80, 0x00, 0x07, 0xf2, 0x00, 0x0a, 0xfd, 0xc0, 0x0c, 0xff, 0x50, 0x00, 0xff, 0x96, 0x00,
    0xff, 0x9e, 0x00, 0xff, 0xa6, 0x00, 0xff, 0xae, 0x00, 0xff, 0xb6, 0x00, 0xff, 0xbf, 0x00, 0xff,
    0xc8, 0x00, 0xff, 0xd1, 0x00, 0xff, 0xda, 0x00, 0xff, 0xe3, 0x00, 0xff, 0xed, 0x00, 0xff, 0xf7,
    0x04, 0xb0, 0x00, 0x09, 0xfb, 0x00, 0x0c, 0xff, 0x40, 0x00, 0xff, 0x8f, 0x00, 0xff, 0x97, 0x00,
    0xff, 0x9f, 0x00, 0xff, 0xa7, 0x00, 0xff, 0xaf, 0x00, 0xff, 0xb7, 0x00, 0xff, 0xc0, 0x00, 0xff,
    0xc9, 0x00, 0xff, 0xd2, 0x00, 0xff, 0xdb, 0x00, 0xff, 0xe4, 0x00, 0xff, 0xee, 0x00, 0xff, 0xf8,
    0x05, 0xd0, 0x00, 0x0b, 0xfe, 0xc0, 0x00, 0xff, 0x89, 0x00, 0xff, 0x90, 0x00, 0xff, 0x98, 0x00,
    0xff, 0xa0, 0x00, 0xff, 0xa8, 0x00, 0xff, 0xb0, 0x00, 0xff, 0xb8, 0x00, 0xff, 0xc1, 0x00, 0xff,
    0xca, 0x00, 0xff, 0xd3, 0x00, 0xff, 0xdc, 0x00, 0xff, 0xe5, 0x00, 0xff, 0xef, 0x00, 0xff, 0xf9,
    0x07, 0xf0, 0x00, 0x00, 0xff, 0x84, 0x00, 0xff, 0x8a, 0x00, 0xff, 0x91, 0x00, 0xff, 0x99, 0x00,
    0xff, 0xa1, 0x00, 0xff, 0xa9, 0x00, 0xff, 0xb1, 0x00, 0xff, 0xb9, 0x00, 0xff, 0xc2, 0x00, 0xff,
    0xcb, 0x00, 0xff, 0xd4, 0x00, 0xff, 0xdd, 0x00, 0xff, 0xe6, 0x00, 0xff, 0xf0, 0x00, 0xff, 0xfa,
    0x08, 0xf8, 0x00, 0x00, 0xff, 0x85, 0x00, 0xff, 0x8b, 0x00, 0xff, 0x92, 0x00, 0xff, 0x9a, 0x00,
    0xff, 0xa2, 0x00, 0xff, 0xaa, 0x00, 0xff, 0xb2, 0x00, 0xff, 0xba, 0x00, 0xff, 0xc3, 0x00, 0xff,
    0xcc, 0x00, 0xff, 0xd5, 0x00, 0xff, 0xde, 0x00, 0xff, 0xe7, 0x00, 0xff, 0xf1, 0x00, 0xff, 0xfb,
    0x0a, 0xfd, 0x80, 0x00, 0xff, 0x86, 0x00, 0xff, 0x8c, 0x00, 0xff, 0x93, 0x00, 0xff, 0x9b, 0x00,
    0xff, 0xa3, 0x00, 0xff, 0xab, 0x00, 0xff, 0xb3, 0x00, 0xff, 0xbb, 0x00, 0xff, 0xc4, 0x00, 0xff,
    0xcd, 0x00, 0xff, 0xd6, 0x00, 0xff, 0xdf, 0x00, 0xff, 0xe8, 0x00, 0xff, 0xf2, 0x00, 0xff, 0xfc,
    0x00, 0xff, 0x82, 0x00, 0xff, 0x87, 0x00, 0xff, 0x8d, 0x00, 0xff, 0x94, 0x00, 0xff, 0x9c, 0x00,
    0xff, 0xa4, 0x00, 0xff, 0xac, 0x00, 0xff, 0xb4, 0x00, 0xff, 0xbc, 0x00, 0xff, 0xc5, 0x00, 0xff,
    0xce, 0x00, 0xff, 0xd7, 0x00, 0xff, 0xe0, 0x00, 0xff, 0xe9, 0x00, 0xff, 0xf3, 0x00, 0xff, 0xfd,
    0x00, 0xff, 0x83, 0x00, 0xff, 0x88, 0x00, 0xff, 0x8e, 0x00, 0xff, 0x95, 0x00, 0xff, 0x9d, 0x00,
    0xff, 0xa5, 0x00, 0xff, 0xad, 0x00, 0xff, 0xb5, 0x00, 0xff, 0xbd, 0x00, 0xff, 0xc6, 0x00, 0xff,
    0xcf, 0x00, 0xff, 0xd8, 0x00, 0xff, 0xe1, 0x00, 0xff, 0xea, 0x00, 0xff, 0xf4, 0x00, 0xff, 0xfe,
    0x02, 0x00, 0x00, 0x02, 0x00, 0x00, 0x02, 0x40, 0x00, 0x02, 0x80, 0x00, 0x03, 0xc0, 0x00, 0x04,
    0xe0, 0x00, 0x05, 0xf0, 0x00, 0x06, 0xf8, 0x00, 0x07, 0xfc, 0x00, 0x08, 0xfe, 0x00, 0x09, 0xff,
    0x00, 0x0a, 0xff, 0x80, 0x0b, 0xff, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a, 0xfe, 0x80,
    0x02, 0x40, 0x00, 0x04, 0xb0, 0x00, 0x05, 0xd0, 0x00, 0x05, 0xd8, 0x00, 0x06, 0xe8, 0x00, 0x06,
    0xec, 0x00, 0x07, 0xf2, 0x00, 0x07, 0xf4, 0x00, 0x08, 0xf9, 0x00, 0x09, 0xfb, 0x80, 0x09, 0xfc,
    0x00, 0x09, 0xfc, 0x80, 0x09, 0xfd, 0x00, 0x0b, 0xff, 0x20, 0x0e, 0xff, 0x80, 0x0f, 0xff, 0x86,
    0x03, 0x80, 0x00, 0x06, 0xe4, 0x00, 0x08, 0xf7, 0x00, 0x08, 0xf8, 0x00, 0x09, 0xfb, 0x00, 0x0a,
    0xfe, 0x40, 0x0b, 0xfe, 0xe0, 0x0b, 0xff, 0x00, 0x00, 0xff, 0xb7, 0x00, 0xff, 0xc0, 0x00, 0xff,
    0xc9, 0x00, 0xff, 0xd2, 0x00, 0xff, 0xdb, 0x00, 0xff, 0xe4, 0x00, 0xff, 0xed, 0x00, 0xff, 0xf6,
    0x04, 0xa0, 0x00, 0x08, 0xf6, 0x00, 0x0a, 0xfd, 0xc0, 0x0a, 0xfe, 0x00, 0x00, 0xff, 0x97, 0x00,
    0xff, 0x9f, 0x00, 0xff, 0xa7, 0x00, 0xff, 0xaf, 0x00, 0xff, 0xb8, 0x00, 0xff, 0xc1, 0x00, 0xff,
    0xca, 0x00, 0xff, 0xd3, 0x00, 0xff, 0xdc, 0x00, 0xff, 0xe5, 0x00, 0xff, 0xee, 0x00, 0xff, 0xf7,
    0x05, 0xc0, 0x00, 0x09, 0xfa, 0x80, 0x0c, 0xff, 0x60, 0x0c, 0xff, 0x70, 0x00, 0xff, 0x98, 0x00,
    0xff, 0xa0, 0x00, 0xff, 0xa8, 0x00, 0xff, 0xb0, 0x00, 0xff, 0xb9, 0x00, 0xff, 0xc2, 0x00, 0xff,
    0xcb, 0x00, 0xff, 0xd4, 0x00, 0xff, 0xdd, 0x00, 0xff, 0xe6, 0x00, 0xff, 0xef, 0x00, 0xff, 0xf8,
    0x05, 0xc8, 0x00, 0x0b, 0xfe, 0xc0, 0x0f, 0xff, 0x84, 0x00, 0xff, 0x91, 0x00, 0xff, 0x99, 0x00,
    0xff, 0xa1, 0x00, 0xff, 0xa9, 0x00, 0xff, 0xb1, 0x00, 0xff, 0xba, 0x00, 0xff, 0xc3, 0x00, 0xff,
    0xcc, 0x00, 0xff, 0xd5, 0x00, 0xff, 0xde, 0x00, 0xff, 0xe7, 0x00, 0xff, 0xf0, 0x00, 0xff, 0xf9,
    0x06, 0xe0, 0x00, 0x0c, 0xff, 0x50, 0x00, 0xff, 0x8c, 0x00, 0xff, 0x92, 0x00, 0xff, 0x9a, 0x00,
    0xff, 0xa2, 0x00, 0xff, 0xaa, 0x00, 0xff, 0xb2, 0x00, 0xff, 0xbb, 0x00, 0xff, 0xc4, 0x00, 0xff,
    0xcd, 0x00, 0xff, 0xd6, 0x00, 0xff, 0xdf, 0x00, 0xff, 0xe8, 0x00, 0xff, 0xf1, 0x00, 0xff, 0xfa,
    0x07, 0xf0, 0x00, 0x00, 0xff, 0x88, 0x00, 0xff, 0x8d, 0x00, 0xff, 0x93, 0x00, 0xff, 0x9b, 0x00,
    0xff, 0xa3, 0x00, 0xff, 0xab, 0x00, 0xff, 0xb3, 0x00, 0xff, 0xbc, 0x00, 0xff, 0xc5, 0x00, 0xff,
    0xce, 0x00, 0xff, 0xd7, 0x00, 0xff, 0xe0, 0x00, 0xff, 0xe9, 0x00, 0xff, 0xf2, 0x00, 0xff, 0xfb,
    0x09, 0xfa, 0x00, 0x00, 0xff, 0x89, 0x00, 0xff, 0x8e, 0x00, 0xff, 0x94, 0x00, 0xff, 0x9c, 0x00,
    0xff, 0xa4, 0x00, 0xff, 0xac, 0x00, 0xff, 0xb4, 0x00, 0xff, 0xbd, 0x00, 0xff, 0xc6, 0x00, 0xff,
    0xcf, 0x00, 0xff, 0xd8, 0x00, 0xff, 0xe1, 0x00, 0xff, 0xea, 0x00, 0xff, 0xf3, 0x00, 0xff, 0xfc,
    0x0a, 0xfd, 0x80, 0x00, 0xff, 0x8a, 0x00, 0xff, 0x8f, 0x00, 0xff, 0x95, 0x00, 0xff, 0x9d, 0x00,
    0xff, 0xa5, 0x00, 0xff, 0xad, 0x00, 0xff, 0xb5, 0x00, 0xff, 0xbe, 0x00, 0xff, 0xc7, 0x00, 0xff,
    0xd0, 0x00, 0xff, 0xd9, 0x00, 0xff, 0xe2, 0x00, 0xff, 0xeb, 0x00, 0xff, 0xf4, 0x00, 0xff, 0xfd,
    0x0c, 0xff, 0x40, 0x00, 0xff, 0x8b, 0x00, 0xff, 0x90, 0x00, 0xff, 0x96, 0x00, 0xff, 0x9e, 0x00,
    0xff, 0xa6, 0x00, 0xff, 0xae, 0x00, 0xff, 0xb6, 0x00, 0xff, 0xbf, 0x00, 0xff, 0xc8, 0x00, 0xff,
    0xd1, 0x00, 0xff, 0xda, 0x00, 0xff, 0xe3, 0x00, 0xff, 0xec, 0x00, 0xff, 0xf5, 0x00, 0xff, 0xfe
};

U8 code gZigZagScan[] =     // #define SECTION_ID_ZIG_ZAG_SCAN_TABLE
{
    0x00, 0x01, 0x05, 0x06, 0x0E, 0x0F, 0x1B, 0x1C,
    0x02, 0x04, 0x07, 0x0D, 0x10, 0x1A, 0x1D, 0x2A,
    0x03, 0x08, 0x0C, 0x11, 0x19, 0x1E, 0x29, 0x2B,
    0x09, 0x0B, 0x12, 0x18, 0x1F, 0x28, 0x2C, 0x35,
    0x0A, 0x13, 0x17, 0x20, 0x27, 0x2D, 0x34, 0x36,
    0x14, 0x16, 0x21, 0x26, 0x2E, 0x33, 0x37, 0x3C,
    0x15, 0x22, 0x25, 0x2F, 0x32, 0x38, 0x3B, 0x3D,
    0x23, 0x24, 0x30, 0x31, 0x39, 0x3A, 0x3E, 0x3F
};

U8 code gDQT_Y[] =              // #define SECTION_ID_DQT_Y_TABLE
{
    0x06, 0x04, 0x05, 0x06, 0x05, 0x04, 0x06, 0x06, 0x05, 0x06, 0x07, 0x07, 0x06, 0x08, 0x0a, 0x10,
    0x0a, 0x0a, 0x09, 0x09, 0x0a, 0x14, 0x0e, 0x0f, 0x0c, 0x10, 0x17, 0x14, 0x18, 0x18, 0x17, 0x14,
    0x16, 0x16, 0x1a, 0x1d, 0x25, 0x1f, 0x1a, 0x1b, 0x23, 0x1c, 0x16, 0x16, 0x20, 0x2c, 0x20, 0x23,
    0x26, 0x27, 0x29, 0x2a, 0x29, 0x19, 0x1f, 0x2d, 0x30, 0x2d, 0x28, 0x30, 0x25, 0x28, 0x29, 0x28
};

U8 code gDQT_CbCr[] =           // #define SECTION_ID_DQT_CBCR_TABLE
{
    0x07, 0x07, 0x07, 0x0a, 0x08, 0x0a, 0x13, 0x0a, 0x0a, 0x13, 0x28, 0x1a, 0x16, 0x1a, 0x28, 0x28,
    0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28
};


//
//      MJPG Headrer 
//

U8 code gMjpgHeader[] =                     // #define SECTION_ID_MJPG_HEADER_TABLE
{
    // SOI, Start Of Image, 2 bytes
    0xff, 0xd8,

    // DQT, Q Table Y, 69 bytes
    0xff, 0xdb, 0x00, 0x43, 0x00,
    // Be set at runtime
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,

    // DQT, Q Table Cb/Cr, 69 bytes
    0xff, 0xdb, 0x00, 0x43, 0x01,
    // Be set at runtime
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,

    // SOF, Start Of Frame, 19 color/13 black and white
    0xff, 0xc0, 0x00, 0x11, 0x08, 0x00, 0xf0, 0x01, 0x40, 0x03, 0x01, 0x21, 0x00, 0x02, 0x11, 0x01,
    0x03, 0x11, 0x01,

    // DHT, Huffman Table, Luminance Y DC Diff, 33 bytes
    0xff, 0xc4, 0x00, 0x1f, 0x00, 0x00, 0x01, 0x05, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a,
    0x0b,

    // DHT, Huffman Table, Luminance Y AC Coeff, 183 bytes
    0xff, 0xc4, 0x00, 0xb5, 0x10, 0x00, 0x02, 0x01, 0x03, 0x03, 0x02, 0x04, 0x03, 0x05, 0x05, 0x04,
    0x04, 0x00, 0x00, 0x01, 0x7d, 0x01, 0x02, 0x03, 0x00, 0x04, 0x11, 0x05, 0x12, 0x21, 0x31, 0x41,
    0x06, 0x13, 0x51, 0x61, 0x07, 0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xa1, 0x08, 0x23, 0x42, 0xb1,
    0xc1, 0x15, 0x52, 0xd1, 0xf0, 0x24, 0x33, 0x62, 0x72, 0x82, 0x09, 0x0a, 0x16, 0x17, 0x18, 0x19,
    0x1a, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44,
    0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64,
    0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x83, 0x84,
    0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2,
    0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9,
    0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7,
    0xd8, 0xd9, 0xda, 0xe1, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf1, 0xf2, 0xf3,
    0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa,

    // DHT, Huffman Table, Chrominance CbCr DC Diff, 33 bytes
    0xff, 0xc4, 0x00, 0x1f, 0x01, 0x00, 0x03, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a,
    0x0b,

    // DHT, Huffman Table, Chrominance CbCr DC Coeff, 183 bytes
    0xff, 0xc4, 0x00, 0xb5, 0x11, 0x00, 0x02, 0x01, 0x02, 0x04, 0x04, 0x03, 0x04, 0x07, 0x05, 0x04,
    0x04, 0x00, 0x01, 0x02, 0x77, 0x00, 0x01, 0x02, 0x03, 0x11, 0x04, 0x05, 0x21, 0x31, 0x06, 0x12,
    0x41, 0x51, 0x07, 0x61, 0x71, 0x13, 0x22, 0x32, 0x81, 0x08, 0x14, 0x42, 0x91, 0xa1, 0xb1, 0xc1,
    0x09, 0x23, 0x33, 0x52, 0xf0, 0x15, 0x62, 0x72, 0xd1, 0x0a, 0x16, 0x24, 0x34, 0xe1, 0x25, 0xf1,
    0x17, 0x18, 0x19, 0x1a, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43,
    0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63,
    0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x82,
    0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99,
    0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7,
    0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5,
    0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf2, 0xf3,
    0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa,

    // SOS, Start Of Scan, 14 color/13 black and white.
    0xff, 0xda, 0x00, 0x0c, 0x03, 0x01, 0x00, 0x02, 0x11, 0x03, 0x11, 0x00, 0x3f, 0x00,
};


//
//      Codec Vtime Table 
//

U8 code gCodec_Vtime_table[] =                      // #define SECTION_ID_CODEC_VTIME_TABLE
{
    // VTIME(8) WIDTH(16)    Height(16)   fps(8) Intr_Prog(8) U2YEobLimit(8) U2CompressRate(8) U3YEobLimit(8) U3ComressRate(8) SensorAttrVHSync(8)
    0x00,       0x00, 0x00,  0x00, 0x00,  0x00,  0x0,         0x00,          0x00,             0x00,          0x00,            0x00,
  
    0x01,       0x80, 0x02,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x02,       0xd0, 0x02,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x03,       0xd0, 0x02,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x04,       0x00, 0x05,  0xd0, 0x02,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x05,       0x80, 0x07,  0x1c, 0x02,  0x3c,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x06,       0xa0, 0x05,  0xf0, 0x00,  0x3c,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x07,       0xa0, 0x05,  0xf0, 0x00,  0x3c,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x08,       0xa0, 0x05,  0xf0, 0x00,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x09,       0xa0, 0x05,  0xf0, 0x00,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x0a,       0x40, 0x0b,  0xf0, 0x00,  0x3c,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x0b,       0x40, 0x0b,  0xf0, 0x00,  0x3c,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x0c,       0x40, 0x0b,  0xf0, 0x00,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x0d,       0x40, 0x0b,  0xf0, 0x00,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x0e,       0xa0, 0x05,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x0f,       0xa0, 0x05,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x10,       0x80, 0x07,  0x38, 0x04,  0x3c,  0x1,         0x16,          0x14,             0x3F,          0x28,            0x03,
    0x11,       0xd0, 0x02,  0x40, 0x02,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x12,       0xd0, 0x02,  0x40, 0x02,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x13,       0x00, 0x05,  0xd0, 0x02,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x14,       0x80, 0x07,  0x1c, 0x02,  0x32,  0x0,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0x15,       0xa0, 0x05,  0x20, 0x01,  0x32,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x16,       0xa0, 0x05,  0x20, 0x01,  0x32,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x17,       0xa0, 0x05,  0x20, 0x01,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x18,       0xa0, 0x05,  0x20, 0x01,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x19,       0x40, 0x0b,  0x20, 0x01,  0x32,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x1a,       0x40, 0x0b,  0x20, 0x01,  0x32,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x1b,       0x40, 0x0b,  0x20, 0x01,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x1c,       0x40, 0x0b,  0x20, 0x01,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x1d,       0xa0, 0x05,  0x40, 0x02,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x1e,       0xa0, 0x05,  0x40, 0x02,  0x32,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x1f,       0x80, 0x07,  0x38, 0x04,  0x32,  0x1,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0x20,       0x80, 0x07,  0x38, 0x04,  0x18,  0x1,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0x21,       0x80, 0x07,  0x38, 0x04,  0x19,  0x1,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0x22,       0x80, 0x07,  0x38, 0x04,  0x1e,  0x1,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0x23,       0x40, 0x0b,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x24,       0x40, 0x0b,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x25,       0x40, 0x0b,  0x40, 0x02,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x26,       0x40, 0x0b,  0x40, 0x02,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x27,       0x80, 0x07,  0x1c, 0x02,  0x32,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x28,       0x80, 0x07,  0x1c, 0x02,  0x64,  0x0,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0x29,       0x00, 0x05,  0xd0, 0x02,  0x64,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x2a,       0xd0, 0x02,  0x40, 0x02,  0x64,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x2b,       0xd0, 0x02,  0x40, 0x02,  0x64,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x2c,       0xa0, 0x05,  0x20, 0x01,  0x64,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x2d,       0xa0, 0x05,  0x20, 0x01,  0x64,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x2e,       0x80, 0x07,  0x1c, 0x02,  0x78,  0x0,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0x2f,       0x00, 0x05,  0xd0, 0x02,  0x78,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x30,       0xd0, 0x02,  0xe0, 0x01,  0x78,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x31,       0xd0, 0x02,  0xe0, 0x01,  0x78,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x32,       0xa0, 0x05,  0xf0, 0x00,  0x78,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x33,       0xa0, 0x05,  0xf0, 0x00,  0x78,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x34,       0xd0, 0x02,  0x40, 0x02,  0xc8,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x35,       0xd0, 0x02,  0x40, 0x02,  0xc8,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x36,       0xa0, 0x05,  0x20, 0x01,  0xc8,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x37,       0xa0, 0x05,  0x20, 0x01,  0xc8,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x38,       0xd0, 0x02,  0xe0, 0x01,  0xf0,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x39,       0xd0, 0x02,  0xe0, 0x01,  0xf0,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x3a,       0xa0, 0x05,  0xf0, 0x00,  0xf0,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x3b,       0xa0, 0x05,  0xf0, 0x00,  0xf0,  0x0,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x80,       0x80, 0x02,  0x5e, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x84,       0x80, 0x02,  0x90, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x88,       0xd0, 0x02,  0x90, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x8c,       0x80, 0x02,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x90,       0x20, 0x03,  0x58, 0x02,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x94,       0x50, 0x03,  0xe0, 0x01,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x98,       0x00, 0x04,  0x00, 0x03,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0x9c,       0x80, 0x04,  0x60, 0x03,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xa0,       0x00, 0x05,  0x00, 0x03,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xa4,       0x00, 0x05,  0xc0, 0x03,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xa8,       0x00, 0x05,  0x00, 0x04,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xac,       0x50, 0x05,  0x00, 0x03,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xb0,       0x78, 0x05,  0x1a, 0x04,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xb4,       0xa0, 0x05,  0x84, 0x03,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xb8,       0x40, 0x06,  0xb0, 0x04,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xbc,       0x90, 0x06,  0x1a, 0x04,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xc0,       0x00, 0x07,  0x40, 0x05,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xc4,       0x40, 0x07,  0x70, 0x05,  0x3c,  0x1,         0x24,          0x28,             0x3F,          0x32,            0x03,
    0xc8,       0x80, 0x07,  0xb0, 0x04,  0x3c,  0x1,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0xcc,       0x80, 0x07,  0xa0, 0x05,  0x3c,  0x1,         0x20,          0x14,             0x3F,          0x28,            0x03,
    0xFF,       0x00, 0x00,  0x00, 0x00,  0x00,  0x0,         0x00,          0x00,             0x00,          0x00,            0x03,
};



